use Perlmazing qw(_isa_ref);

sub main ($) {
	_isa_ref('VSTRING', $_[0]);
}

